#ifndef _TIMER_H_
#define _TIMER_H_

enum timer_instance {
    TIMER_1,
    TIMER_2,
    TIMER_3,
    TIMER_4
};

enum timer_mode {
    ONE_SHOT, // counts down to zero, interrupts(if enabled) and stops
    PERIODIC // counts down to zero, interrupts, reloads the counter register and start counting down again.
};

// power on/power off the given timer instance
void timer_enable(enum timer_instance timer);
void timer_disable(enum timer_instance timer);

// sets the timer mode
void timer_set_mode(enum timer_instance timer, enum timer_mode mode);

// The value "val" will be loaded to the count register of the timer
// 1 LSB = 1ms
// max value = 4096
void timer_set_count(enum timer_instance timer, int val);

// gets the value in timer's count register
int timer_get_count(enum timer_instance timer);

// Resets the count register of the timer
void timer_clear_count(enum timer_instance timer);

// start/stop the timer operation
void timer_start(enum timer_instance timer);
void timer_stop(enum timer_instance timer);

// enable/disable timer interrupt
void timer_interrupt_enable(enum timer_instance timer);
void timer_interrupt_disable(enum timer_instance timer);

// Tells us which timer instance gave the interrupt
enum timer_instance timer_get_interrupt_source();

#endif